pub enum Error {
Show 22 variants
BadStateChange(String),
BadDkgId(u64, u64),
BadSignId(u64, u64),
BadSignIterId(u64, u64),
MaliciousSigner(u32),
Aggregator(AggregatorError),
SchnorrProofFailed,
MissingAggregatePublicKey,
MissingSchnorrProof,
MissingSignature,
MissingMessageNonceInfo,
MissingPublicKeyForSigner(u32),
MissingKeyIDsForSigner(u32),
BadKeyIDsForSigner(u32),
DkgFailure {
reported_failures: HashMap<u32, DkgFailure>,
malicious_signers: HashSet<u32>,
},
AggregateKeyPolynomialMismatch(Point, Point),
DuplicatePartyId,
MissingCoordinatorPublicKey,
InvalidPacketSignature,
NoPublicSharesForSigner(u32),
Point(Error),
TryFromInt(TryFromIntError),
}Expand description
The error type for the coordinator
Variants
BadStateChange(String)
A bad state change was made
BadDkgId(u64, u64)
A bad dkg_id in received message
BadSignId(u64, u64)
A bad sign_id in received message
BadSignIterId(u64, u64)
A bad sign_iter_id in received message
MaliciousSigner(u32)
A malicious signer sent the received message
Aggregator(AggregatorError)
SignatureAggregator error
SchnorrProofFailed
Schnorr proof failed to verify
MissingAggregatePublicKey
No aggregate public key set
MissingSchnorrProof
No schnorr proof set
MissingSignature
No signature set
MissingMessageNonceInfo
Missing message response information for a signing round
MissingPublicKeyForSigner(u32)
Missing public key for signer
MissingKeyIDsForSigner(u32)
Missing key IDs for signer
BadKeyIDsForSigner(u32)
Bad key IDs for signer
DkgFailure
DKG failure from signers, with a map of signer_id to reported errors and new malicious signer_ids
Fields
reported_failures: HashMap<u32, DkgFailure>failures reported by signers during DkgEnd
AggregateKeyPolynomialMismatch(Point, Point)
Aggregate key does not match supplied party polynomial
DuplicatePartyId
Supplied party polynomial contained duplicate party IDs
MissingCoordinatorPublicKey
Missing coordinator public key“
InvalidPacketSignature
A packet had an invalid signature
No public shares for the signer who sent private shares
Point(Error)
A curve point error
TryFromInt(TryFromIntError)
An error during integer conversion operations