pub struct Config {
pub num_signers: u32,
pub num_keys: u32,
pub threshold: u32,
pub dkg_threshold: u32,
pub message_private_key: Scalar,
pub dkg_public_timeout: Option<Duration>,
pub dkg_private_timeout: Option<Duration>,
pub dkg_end_timeout: Option<Duration>,
pub nonce_timeout: Option<Duration>,
pub sign_timeout: Option<Duration>,
pub public_keys: PublicKeys,
pub verify_packet_sigs: bool,
}Expand description
Config fields common to all Coordinators
Fields
num_signers: u32total number of signers
num_keys: u32total number of keys
threshold: u32threshold of keys needed to form a valid signature
dkg_threshold: u32threshold of keys needed to complete DKG (must be >= threshold)
message_private_key: Scalarprivate key used to sign network messages
dkg_public_timeout: Option<Duration>timeout to gather DkgPublicShares messages
dkg_private_timeout: Option<Duration>timeout to gather DkgPrivateShares messages
dkg_end_timeout: Option<Duration>timeout to gather DkgEnd messages
nonce_timeout: Option<Duration>timeout to gather nonces
sign_timeout: Option<Duration>timeout to gather signature shares
public_keys: PublicKeysthe public keys and key_ids for all signers
verify_packet_sigs: boolwhether to verify the signature on Packets
Implementations
Sourceimpl Config
impl Config
Sourcepub fn new(
num_signers: u32,
num_keys: u32,
threshold: u32,
message_private_key: Scalar,
) -> Self
pub fn new( num_signers: u32, num_keys: u32, threshold: u32, message_private_key: Scalar, ) -> Self
Create a new config object with no timeouts
Sourcepub fn with_timeouts(
num_signers: u32,
num_keys: u32,
threshold: u32,
dkg_threshold: u32,
message_private_key: Scalar,
dkg_public_timeout: Option<Duration>,
dkg_private_timeout: Option<Duration>,
dkg_end_timeout: Option<Duration>,
nonce_timeout: Option<Duration>,
sign_timeout: Option<Duration>,
public_keys: PublicKeys,
) -> Self
pub fn with_timeouts( num_signers: u32, num_keys: u32, threshold: u32, dkg_threshold: u32, message_private_key: Scalar, dkg_public_timeout: Option<Duration>, dkg_private_timeout: Option<Duration>, dkg_end_timeout: Option<Duration>, nonce_timeout: Option<Duration>, sign_timeout: Option<Duration>, public_keys: PublicKeys, ) -> Self
Create a new config object with the passed timeouts